@@ -1,6 +1,6 @@
 import typing
 import ast
-from tex.exceptions import TemplateError, TemplateContextError, TemplateSyntaxError
+from tex_engine.exceptions import TemplateError, TemplateContextError, TemplateSyntaxError
 
 def eval_expression(expr) -> typing.Tuple[str, typing.Any]:
     try:
