@@ -1,4 +1,4 @@
-from tex.compiler import Compiler
+from tex_engine.compiler import Compiler
 
 class Template(object):
     def __init__(self, contents):
